@@ -15,6 +15,9 @@ pub mod future;
 
 #[cfg(feature = "cache")]
 mod cache;
+#[cfg(feature = "fs")]
+#[cfg_attr(docsrs, doc(cfg(feature = "fs")))]
+pub mod fs;
 #[cfg(feature = "json")]
 mod json;
 
@@ -23,6 +26,9 @@ pub use self::cache::CacheBackend;
 #[cfg(feature = "cache")]
 #[cfg_attr(feature = "cache", doc(hidden))]
 pub use self::cache::CacheError;
+#[cfg(feature = "fs")]
+#[cfg_attr(feature = "fs", doc(hidden))]
+pub use self::fs::FsError;
 #[cfg(feature = "json")]
 pub use self::json::JsonBackend;
 #[cfg(feature = "json")]
